/*---------------------------------------------------------------------------------------------------

Project Name
**************************
 
POVERTY AND MALNUTRITION IN THE DEMOCRATIC REPUBLIC OF THE CONGO: 
SECONDARY DATA ANALYSIS FINDINGS FROM THE PROVINCES OF TANGANYIKA, KASAI, AND KASAI CENTRAL
 
LASER PULSE
Long-term Assistance and SErvices for Research (LASER)
Partners for University-Led Solutions Engine (PULSE)

Data: MICS6 2017-2018, DRC
Malnutrition analyses

SUGGESTED CITATION
Alia, D., Kibriya, S., Connaughton, S. L., Fatema, N., Sagbo, S., and Kasa, L. 2023. Poverty and
Malnutrition in the Democratic Republic of the Congo (DRC): Secondary Data Analysis (SDA)
Findings from the Provinces of Tanganyika, Kasai, and Kasai Central. West Lafayette, IN: Long-
term Assistance and Services for Research - Partners for University-Led Solutions Engine
(LASER PULSE Consortium).
  
Created: August 20, 2022

---------------------------------------------------------------------------------------------------*/
 
*## Set paths for directories and files
global path 			"C:\Users\dyali\OneDrive\BHA_DRC_SDA"
global path 			"C:\Users\dyalia\dyalia_OneDrive\OneDrive\BHA_DRC_SDA"

global raw_data 		"${path}/Raw_data/DRCongo MICS6 SPSS Datafiles/Stata"
global created_data 	"${path}/Created_data"
global output		 	"${path}/Output"

*## Create the excel file where the estimates will be outputted
clear matrix
putexcel set "${output}/BHA_DRC_SDA_DRC_SDA Wasting Summary statistics_January_2023.xls", replace
putexcel set "${output}/BHA_DRC_SDA_DRC_SDA Stunting Summary statistics_January_2023.xls", replace


*## Uncomment and run the following four lines of code once if the commands are not yet installed
*ssc install matodd
*ssc install matewd
*ssc install coefplot 
*ssc install outreg2
*ssc install estout

/*
Please register with the MICS team to obtain access to the raw data.
These data come as spss (.sav) file. They can be first converted to stata (.dta) files
by opening the spss file (with SPSS) and then by clicking 'save as' and choosing 'stata' as the file type.
The stata file must saved in the folder referenced in the path "${raw_data}"
*/

//============================================================================//
//																	          //
//									Child Malnutrition						  //
//																			  //
//============================================================================//
*## Tag the focus provinces for the analysis
global focus_provinces "21, 25, 26"  //16-South Kivu, 21-Tanganyika, 23-Kasai Oriental, 25-Kasai Central, and 26-Kasai
global cfocus_provinces "21 25 26"  //16-South Kivu, 21-Tanganyika, 23-Kasai Oriental, 25-Kasai Central, and 26-Kasai
global nfocus_provinces "Tanganyika Kasai_Central Kasai"


*Individual characteristics (for mothers)
use "${raw_data}/hl.dta", clear
duplicates report HH1 HH2 HL1
gen  UF4=HL1  //UF4 is mother id in the anthropometric file

gen mother_age=HL6
recode mother_age (95/100=.)
gen mother_noschool=inlist(ED5A,.,0)
gen mother_primary=inlist(ED5A,10)
gen mother_secondary=inlist(ED5A,20,31,32,34,34,40)
gen mother_ishh=HL3==1
gen mother_isspousehh=HL3==2
gen mother_isdaughterhh=HL3==3
gen mother_isdaughterILhh=HL3==4
duplicates report HH1 HH2 UF4
gen mother_id=UF4
save "${raw_data}/hl_mother.dta", replace


*Individual characteristics (for child)
use "${raw_data}/hl.dta", clear
duplicates report HH1 HH2 HL1
gen  UF3=HL1  //UF3 is chilld id in the anthropometric file
gen child_sondaughtherhh=HL3==3
gen child_liveswithfather=HL18!=.
gen child_liveswithmother=!inlist(HL20,.,90,99)
save "${raw_data}/hl_child.dta", replace

*mother birth history  
use "${raw_data}/bh.dta", clear
drop if BH8==0 | BH8==.

save  "${raw_data}/bh_cleaned.dta", replace


use "${raw_data}/ch.dta", clear
gen BH8=UF3
duplicates report  HH1 HH2 UF3
save "${raw_data}/ch_cleaned.dta", replace
merge 1:1   HH1 HH2 BH8 using "${raw_data}/bh_cleaned.dta", keep(1 3) nogen  //birth history (bit list of individual is incomplete and we lost 1,825 children
merge m:1 HH1 HH2 UF4 using   "${raw_data}/hl_mother.dta", keep(3) nogen  //mother characteristics from hhmember file
merge 1:1 HH1 HH2 UF3 using   "${raw_data}/hl_child.dta", keep(3) nogen  //mother characteristics from hhmember file

*Checking that this file is at the individuals (children under 5) level and has not dupplicates
duplicates report UF1 UF2 UF3  // 21,477 unique observations with no dupplicates

drop if windex5==0  // there 18 households for which we do not have wealth index because these households did not complete the survey. We are excluding them from the analysis

 
*Sample size households
tab HH7 if inlist(HH7,${focus_provinces}), matcell(sample_hh) 
count
matrix sample_hh=sample_hh\r(N)
matrix rownames sample_hh=${nfocus_provinces} DRC_national
matrix colnames sample_hh=Sample_hh
matrix list sample_hh



*Construction of child nutrition indicators
**********************************************************
ren HAZ2 child_height_age_zscore
ren WAZ2 child_weight_age_zscore
ren WHZ2 child_weight_height_zscore
keep if hazflag==0  & wazflag==0  & whzflag ==0 // Keeping only children with no flags on anthrometric measurements (700 obs deleted)
ren zbmi child_bmi


* nutrition indicators
gen child_stunting=child_height_age_zscore<-2 if child_height_age_zscore!=.
lab var child_stunting "1=Stunting (Height-for-age <-2 SD)"
gen child_wasting=child_weight_height_zscore<-2 if child_weight_height_zscore!=.
lab var child_wasting "1=Wasting (Weight-for-height) <-2 SD)"
gen child_underweight=child_weight_age_zscore<-2 if child_weight_age_zscore!=.
lab var child_underweight "1=Underweight (Weight-for-age <-2 SD) "
gen child_overweight=child_weight_age_zscore>2 if child_weight_age_zscore!=.
lab var child_overweight "1=Overweight (Weight-for-age >2 SD)"

egen child_undernourished=rowtotal(child_stunting child_wasting child_underweight)   
recode child_undernourished (1 2 3 =1) // stunted or wasted or underweight
lab var child_undernourished "1=Undernourished (Stunted or Wasted or Underweight)"

* child characteristics
gen child_age_years=UB2
gen child_age_months=cage
gen child_insured=UB9==1
gen child_hasdisability=cdisability==1
gen child_stillbreasfed=BD3==1
gen child_recentdiahrea=CA1==1
gen child_recentfever=CA14==1
gen child_recentcough=CA16==1
gen child_recentrespidiff=CA17==1

gen child_birthrank=brthord
gen mother_ageatbirth=magebrt
gen mother_ageatbirth__20=mother_ageatbirth==1
gen mother_ageatbirth_20_34=mother_ageatbirth==2
gen mother_ageatbirth_35_=mother_ageatbirth==3

gen child_birthinter=birthint
gen child_birthinter_0=child_birthinter==0
gen child_birthinter_1=child_birthinter==1
gen child_birthinter_2=child_birthinter==2
gen child_birthinter_3=child_birthinter==3
gen child_birthinter_4_=child_birthinter==4

gen child_isfemale=HL4==2

*infant feeding practices
gen infant_hasbreasfed=BD2==1
gen infant_notbottled_ystd=BD4==2
*if not bottled
  
gen infant_vitamin_ystd=BD5==1
gen infant_water_sodium_ystd=BD6==1 //Add
gen infant_water_ystd=BD7A==1  //add
gen infant_fruitj_ystd=BD7B==1
gen infant_soup_ystd=BD7C==1
gen infant_formula_ystd=BD7D==1 // add
gen infant_dairy_ystd=BD7E==1
gen infant_otherliqu_ystd=BD7X==1

gen infant_yogurt_ystd=BD8A==1
gen infant_babyfood_ystd=BD8B==1
gen infant_cereal_ystd=BD8C==1
gen infant_ylowveg_ystd=BD8D==1
gen infant_tuber_ystd=BD8E==1
gen infant_greenveg_ystd=BD8F==1
gen infant_fruit_ystd=BD8G==1
gen infant_othfruitveg_ystd=BD8H==1
gen infant_liver_ystd=BD8I==1
gen infant_meat_ystd=BD8J==1
gen infant_eggs_ystd=BD8K==1
gen infant_fish_ystd=BD8L==1
gen infant_beans_ystd=BD8M==1
gen infant_cheese_ystd=BD8N==1
gen infant_snail_ystd=BD8O==1
gen infant_othsolid_ystd=BD8X==1
gen infant_hasvaccard=inlist(IM2,1,2,3)

*grouping food eaten
gen infant_mdd_group1=infant_cereal_ystd==1 | infant_tuber_ystd //1. Grains, roots, and tubers
gen infant_mdd_group2=infant_beans_ystd //2. Pulses
gen infant_mdd_group3=. //3. Nuts and seeds
gen infant_mdd_group4=infant_yogurt_ystd==1 | infant_cheese_ystd==1 | infant_dairy_ystd==1 //4. Dairy
gen infant_mdd_group5=infant_liver_ystd==1 | infant_meat_ystd==1 | infant_snail_ystd==1 | infant_fish_ystd==1 //5. Meat, poultry, and fish
gen infant_mdd_group6=infant_eggs_ystd==1 //6. Eggs
gen infant_mdd_group7=infant_greenveg_ystd==1 //7. Dark leafy greens and vegetables
gen infant_mdd_group8=infant_fruit_ystd==1 | infant_ylowveg_ystd==1 | infant_vitamin_ystd==1 //8. Other Vitamin A-rich fruits and vegetables
gen infant_mdd_group9=infant_othfruitveg_ystd==1 | infant_soup_ystd==1 //9. Other vegetables - might also include fruits
gen infant_mdd_group10=infant_fruitj_ystd==1 // 10.Other fruits

recode infant_mdd_group* infant_water_sodium_ystd infant_water_ystd infant_formula_ystd (min/max=.) if infant_notbottled_ystd!=1
egen infant_mdd_nbgroups=rowtotal(infant_mdd_group*) if infant_notbottled_ystd==1
 
gen infant_mdd_diversity=infant_mdd_nbgroups>=5 if infant_notbottled_ystd==1
lab var infant_mdd_diversity "Infant has diversified diet"

*Histograms
label var child_height_age_zscore "Height-for-age zscores"
label var child_weight_height_zscore "Weight-for-height zscores"
label var child_weight_age_zscore "Weight-for-age zscores"

*Summary statistics
gen windex5_1=windex5==1
gen windex5_2=windex5==2
gen windex5_3=windex5==3
gen windex5_4=windex5==4
gen windex5_5=windex5==5

label var	child_isfemale		"Child is a girl"		
label var	child_birthrank		"Child's birth rank"		
label var	child_birthinter_0		"Child birth interval: 0 year"		
label var	child_birthinter_1		"Child birth interval: 1 year"		
label var	child_birthinter_2		"Child birth interval: 2 year"		
label var	child_birthinter_3		"Child birth interval: 3 year"		
label var	child_birthinter_4_		"Child birth interval: 4+ year"		
label var	child_age_months		"Child age in months"		
label var	child_sondaughtherhh		"Child is HHH son/daughter"		
label var	child_liveswithfather		"Child lives with father"		
label var	child_liveswithmother		"Child lives with mother"		
label var	child_bmi		"Child BMI Z-score"		
label var	child_hasdisability		"Child has disability"		
label var	child_stillbreasfed		"Child is still breastfed"		
label var	child_recentdiahrea		"Child had diahrea"		
label var	child_recentfever		"Child had fever"		
label var	child_recentcough		"Child had cough"		
label var	child_recentrespidiff		"Child had resp. illness"		
										
label var	mother_age		"Mother current age"		
label var	mother_noschool		"Mother eductation: No schooling"		
label var	mother_primary		"Mother eductation: Primary school"		
label var	mother_secondary		"Mother eductation: Secondary school"		
label var	mother_ishh		"Mother is Hhh"		
label var	mother_isspousehh		"Mother is spouse of Hhh" 		
label var	mother_isdaughterhh		"Mother is daughter of Hhh"		
label var	mother_isdaughterILhh		"Mother is DiL of Hhh"		
label var	mother_ageatbirth__20		"Mother' age at child birth < 20" 		
label var	mother_ageatbirth_20_34		"Mother' age at child birth 20-34"		
label var	mother_ageatbirth_35_		"Mother' age at child birth >35"		
												
label var	windex5_1		"HH wealth quintile 1st"		
label var	windex5_2		"HH wealth quintile 2nd"		
label var	windex5_3		"HH wealth quintile 3rd"		
label var	windex5_4		"HH wealth quintile 4th"		
label var	windex5_5		"HH wealth quintile 5th"		

lab var infant_mdd_group1 "Ate grains/roots/tubers"
lab var infant_mdd_group2 "Ate pulses"
lab var infant_mdd_group3 "Ate nuts/seeds"
lab var infant_mdd_group4 "Ate dairy"
lab var infant_mdd_group5 "Ate meat/poultry/fish"
lab var infant_mdd_group6 "Ate eggs"
lab var infant_mdd_group7 "Ate leafy greens and veggies"
lab var infant_mdd_group8 "Ate oth Vit A-rich fruits/veggies"
lab var infant_mdd_group9 "Ate oth vegetables"
lab var infant_mdd_group10 "Ate oth fruits"

lab var infant_water_sodium_ystd "Intake of sodium"
lab var infant_water_ystd "Intake of water"
lab var infant_soup_ystd "Ate soup"
lab var infant_formula_ystd "Intake of formula"
 

merge m:1 HH1 HH2 using  "${raw_data}/household_poverty.dta", nogen keep(1 3)


global child_vars child_isfemale child_birthrank child_birthinter_0 child_birthinter_1 child_birthinter_2 child_birthinter_3 child_birthinter_4_ child_age_months child_sondaughtherhh child_liveswithfather child_liveswithmother child_bmi child_hasdisability child_stillbreasfed child_recentdiahrea child_recentfever child_recentcough child_recentrespidiff
global mother_vars mother_ishh mother_isspousehh mother_isdaughterhh mother_isdaughterILhh mother_age mother_ageatbirth__20  mother_ageatbirth_20_34 mother_ageatbirth_35_ mother_noschool mother_primary mother_secondary mother_secondary

global hhold_vars hh_rural hh_children_5 hh_children_5_17 hh_size hh_age drinkwater_safe  drinkwater_unsafe toilet_modern toilet_tradisafe toilet_opendef water_to_washang bednet windex5_1 windex5_2 windex5_3 windex5_4 windex5_5

global inf_mdd_vars infant_mdd_group1 infant_mdd_group2 /*infant_mdd_group3*/ infant_mdd_group4 infant_mdd_group5 infant_mdd_group6 infant_mdd_group7 infant_mdd_group8 infant_mdd_group9 infant_mdd_group10 infant_mdd_nbgroups infant_mdd_diversity infant_water_sodium_ystd infant_water_ystd infant_formula_ystd


gen windex5_3_=windex5_3==1 | windex5_4==1 | windex5_5==1
lab var windex5_3_ "HH wealth quintile 3rd-5th"

global hhold_vars2 hh_rural hh_childre~5 hh_size hh_age hh_primary hh_secondaryplus eletricity drinkw~_safe toilet_ope~f water_to_w~g   bednet windex5_2 windex5_3_

gen child_birthinter_2_=child_birthinter_2==1 | child_birthinter_3==1 | child_birthinter_4_==1
global child_vars2 child_isfemale child_birthrank child_birthinter_0 child_birthinter_1 child_birthinter_2_ child_age_months child_sondaughtherhh child_liveswithfather child_liveswithmother

global childhealth_vars2 child_bmi child_hasdisability child_stillbreasfed child_recentdiahrea child_recentfever child_recentcough child_recentrespidiff

gen mother_ageatbirth_20_=mother_ageatbirth_20_34==1 | mother_ageatbirth_35_==1
gen mother_secondaryplus=mother_secondary==1 
lab var mother_secondaryplus "Mother education: Secondary+ school"
global mother_vars2 mother_ishh mother_isdaughterhh mother_age mother_ageatbirth__20   mother_primary  mother_secondaryplus

global infant_mdd_vars2 infant_mdd_group1 infant_mdd_group2 /*infant_mdd_group3*/ infant_mdd_group4 infant_mdd_group5 infant_mdd_group6 infant_mdd_group7 infant_mdd_group8 infant_mdd_group9 infant_mdd_group10 infant_mdd_diversity infant_water_sodium_ystd infant_water_ystd infant_formula_ystd

lab var  HH1  "Enumeration area"
lab var  HH2  "Household ID"
lab var  UF4  "Mother ID"
lab var  UB2  "Child age"
lab var  UB9  "Has health insurance"
lab var  BD2  "Has been breastfed"
lab var  BD3  "Still breastfeeding"
lab var  BD4  "Bottle"
lab var  BD5  "Hydration water"
lab var  BD6  "Vitamins"
lab var  BD7A  "Water"
lab var  BD7B  "Juice"
lab var  BD7C  "Soup"
lab var  BD7D  "Formula"
lab var  BD7E  "Milk"
lab var  BD7X  "Other liquid food"
lab var  BD8A  "Yogurt"
lab var  BD8B  "Baby food"
lab var  BD8C  "Grains and cereals"
lab var  BD8D  "Fruits"
lab var  BD8E  "Roots and tubers"
lab var  BD8F  "Vegetables"
lab var  BD8G  "Fruits"
lab var  BD8H  "Other fruits"
lab var  BD8I  "other meat"
lab var  BD8J  "Other meat"
lab var  BD8K  "Eggs"
lab var  BD8L  "Fish"
lab var  BD8M  "Beans"
lab var  BD8N  "Cheese"
lab var  BD8O  "snails"
lab var  IM2  "Has vaccination card"
lab var  CA1  "Diahrea"
lab var  CA14  "Fever"
lab var  CA16  "Cough"
lab var  CA17  "Respiratory illness"
lab var  HL4  "Sex"
lab var  ED5A  "Child education level"
lab var  cage  "Child age category"
lab var  cdisability  "Child has disability"
lab var  windex5  "Wealth quintile"
lab var  brthord  "Child birth rank"
lab var  magebrt  "Mother's age at child birth"
lab var  birthint  "Child birth interval"
lab var  HL1  "Child ID"
lab var  HL3  "Relationship to household head"
lab var  HL6  "Age"
lab var  HL18  "Father ID"
lab var  HL20  "Caregiver ID"
lab var  mother_id  "Mother ID"
lab var  child_age~rs  "Child age in years"
lab var  child_insu~d  "Child has health insurance"
lab var  mother_age~h  "Mother age in years"
lab var  child_birt~r  "Child birth interval"
lab var  BH8 "Child ID"
lab var  infant_mdd_nbgroups "MDD number of food groups"
lab var  child_birthinter_2_ "Child birth interval >2"
lab var  mother_ageatbirth_20_ "Mother age >20"
lab var hhweight  "Survey weight"

keep $child_vars $mother_vars $hhold_vars $inf_mdd_vars $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 /*
*/  HH1 HH2 HL1 HL3 UF4 HL6 ED5A HL18 HL20 BH8 HH7 UB2 cage UB9 cdisability BD3 CA1 /*
*/ CA14 CA16 CA17 brthord magebrt birthint HL4 BD2 BD4 BD5 BD6 BD7A BD7B BD7C /*
*/ BD7D BD7E BD7X BD8A BD8B BD8C BD8D BD8E BD8F BD8G BD8H BD8I BD8J BD8K BD8L /*
*/ BD8M BD8N BD8O BD8O IM2 windex5 hhweight stratum child_* mother_* hh_*
*compress
quietly {
    log using "C:\Users\dyalia\dyalia_OneDrive\OneDrive\BHA_DRC_SDA\codebook_child_nutrition.txt", text replace
    noisily codebook, c
    log close
}
save "${raw_data}/child_nutrition.dta", replace 


*## Figure 7: Distribution of z-scores of nutrition indicators by child age and province 

use "${raw_data}/child_nutrition.dta",  clear
*DRC National
local tit_child_height_age_zscore "Height-for-age zscores"
local tit_child_weight_height_zscore "Weight-for-Height zscores"
local tit_child_weight_age_zscore "Weight-for-age zscores"

twoway (hist child_weight_height_zscore, frac fcolor(none) lcolor(blue*0.7) ) ///
       (hist child_height_age_zscore, frac fcolor(none) lcolor(green*0.7)),  ///
	   leg( order(1 "Weight-for-height"  2 "Height-for-age"))  xline(-2) xlab(-6(2)6) ///
	   title ("Distribution of zscores" "DRC National")
graph export "${output}\Hist_zscores_wasting_stunting_combined_DRC_National.pdf", replace


preserve
collapse (mean) child_height_age_zscore child_weight_height_zscore child_weight_age_zscore, by(child_age_months child_isfemale)
foreach nutri in child_height_age_zscore child_weight_height_zscore child_weight_age_zscore {
	twoway (scatter `nutri' child_age_months if child_isfemale==1, connect(l) msymbol(h)) ///
	(scatter `nutri' child_age_months if child_isfemale==0, connect(l) msymbol(d)) ///
	, xtitle("Child age in months") xlab(0(5)60) title("Mean `tit_`nutri'' by age and sex" "DRC National")  ///
	legend(order(1 "Girls" 2 "Boys"))
	graph export "${output}\Scatter_age_`nutri'_DRC_National.pdf", replace
}
restore


*By province
foreach p of global cfocus_provinces {	
	di "`p'"
	if "`p'" =="21" {
		local province "Tanganyika" 
	}
	if "`p'" =="25" {
		local province "Kasai Central" 
	}	
	if "`p'" =="26" {
		local province "Kasai" 
	}	
	/*foreach nutri in child_height_age_zscore child_weight_height_zscore child_weight_age_zscore {
		hist `nutri' if HH7==`p', color(black*0.5) title ("Distribution of `tit_`nutri''" "`province'", size(large)) normal
		graph export "${output}\Hist_zscores_wasting_stunting_combined__`province'.pdf", replace
	}
*/
	preserve
	keep if HH7==`p'
	twoway (hist child_weight_height_zscore, frac fcolor(none) lcolor(blue*0.7) ) ///
		   (hist child_height_age_zscore, frac fcolor(none) lcolor(green*0.7)),  ///
		   leg( order(1 "Weight-for-height"  2 "Height-for-age"))  xline(-2) xlab(-6(2)6) ///
		   title ("Distribution of zscores" "`province'")
	graph export "${output}\Hist_zscores_wasting_stunting_combined_`province'.pdf", replace
	
	
	collapse (mean) child_height_age_zscore child_weight_height_zscore, by(child_age_months)

	twoway (scatter child_weight_height_zscore child_age_months, connect(l) msymbol(h)) ///
		   (scatter child_height_age_zscore child_age_months, connect(l) msymbol(d)),  ///
			xtitle("Child age in months", size(large)) xlab(0(5)60, labsize(large)) title("Mean zscores by age" "`province'", size(large))  ///
			legend(order(1 "Weight-for-height" 2 "Height-for-age"))
			graph export "${output}\Scatter_age_wasting_stunting_combined_`province'.pdf", replace
	restore	
}

*## Figure 8: Prevalence of wasting among children under five 
*## Figure 9: Prevalence of stunting among children under five
*Percent of child malnourished
preserve
collapse (mean) child_stunting child_wasting child_underweight child_undernourished [aw=hhweight], by(hh_rural)
gen HH7=9999
tempfile drc_rurur
save `drc_rurur'
restore

preserve
collapse (mean) child_stunting child_wasting child_underweight child_undernourished [aw=hhweight]
gen HH7=9999
gen hh_rural=10
tempfile drc
save `drc'
restore


preserve
collapse (mean) child_stunting child_wasting child_underweight child_undernourished [aw=hhweight], by(HH7 hh_rural)
keep if inlist(HH7,$focus_provinces)
tempfile province_rurur
save `province_rurur'
restore

preserve
collapse (mean) child_stunting child_wasting child_underweight child_undernourished [aw=hhweight], by(HH7)
keep if inlist(HH7,$focus_provinces)
gen hh_rural=10
tempfile province
save `province'
restore

preserve
use `province', clear
append using `province_rurur'
append using `drc'
append using `drc_rurur'
export excel using "${output}\BHA_DRC_SDA Summary statistics - nutrition_October_2022.xls", replace firstrow(variables)
restore

use "${raw_data}/child_nutrition.dta",  clear


*## Table 14-20
*Wasting==================
**ALL HOUSEHOLDS
foreach typs in child mother hhold inf_mdd {
*DRC National	
	*Distribution among all, poor and non-poor households
	matrix ttest_`typs'_vars=J(1,7,.)
	global stat_vars ""
	*di "$stat_`typs'_vars"	
	foreach x of global `typs'_vars {
		qui tabstat `x' [aw=hhweight], by(child_wasting)   statistics (mean semean) save // to get means that reflect the survey weights
		matrix meangroup=100*r(StatTotal)', 100*r(Stat2)',100*r(Stat1)'
		qui reg `x' child_wasting [aw=hhweight] // to get pvalues that reflect the survey weights
		matrix b=e(b)
		matrix V=e(V)
		scalar pvalue=(2*ttail(e(df_r), abs(el(b,1,1)/sqrt(el(V,1,1)))))
		matrix ttest_`typs'_vars=ttest_`typs'_vars\(meangroup,pvalue)
		global stat_vars $stat_vars Mean_`x'  
	}


	matrix ttest_`typs'_vars=ttest_`typs'_vars[2..rowsof(ttest_`typs'_vars),.]
	matrix rownames ttest_`typs'_vars=$stat_vars
	matrix colnames ttest_`typs'_vars= Mean_all SE_all  Mean_child_wasting SE_child_wasting Mean_nonchild_wasting SE_nonchild_wasting  Pvalue 

	*Wasting incidence among all, poor and non-poor households
	matrix pov_`typs'_vars=J(1,4,.)
	foreach x of global `typs'_vars {
		qui tabstat child_wasting [aw=hhweight], by(`x')   statistics (mean semean) save // to get means that reflect the survey weights
		capture confirm matrix r(Stat2)
		if _rc==0 { 
			matrix meangroup=100*r(Stat2)',100*r(Stat1)'
		}
		if _rc!=0 { 
			matrix meangroup=J(1,4,.)
		}		
		matrix pov_`typs'_vars=pov_`typs'_vars\meangroup	
	}

	matrix pov_`typs'_vars=pov_`typs'_vars[2..rowsof(pov_`typs'_vars),.]
	matrix rownames pov_`typs'_vars=$stat_vars
	matrix colnames pov_`typs'_vars= Pov_Mean_child_wasting Pov_SE_child_wasting Pov_Mean_nonchild_wasting  Pov_SE_nonchild_wasting
	
	matrix pov_`typs'_vars_combined=ttest_`typs'_vars, J(rowsof(ttest_`typs'_vars),1,.), pov_`typs'_vars
	matrix list pov_`typs'_vars_combined
	
	putexcel set "${output}/BHA_DRC_SDA Wasting Summary statistics_January_2023.xls", sheet("`typs'_vars - child_wasting", replace) modify
	qui putexcel A2="ALL HOUSEHOLDS" 
	qui putexcel A4="Wasting Summary Statistics - `typs'_vars" 
	qui putexcel A6="DRC National" 
	qui putexcel A8 =matrix(pov_`typs'_vars_combined) , names

	
*By province
	*Distribution among all, poor and non-poor households
	local n: word count $`typs'_vars 
	di "`n'"
	foreach p of global cfocus_provinces {	
		di "`p'"
		matrix ttest_`typs'_vars_`p'=J(1,7,.)
		foreach x of global `typs'_vars {
			qui tabstat `x' [aw=hhweight] if HH7==`p', by(child_wasting)   statistics (mean semean) save // to get means that reflect the survey weights
			matrix meangroup=100*r(StatTotal)', 100*r(Stat2)',100*r(Stat1)'
			qui reg `x' child_wasting [aw=hhweight] if HH7==`p' // to get pvalues that reflect the survey weights
			matrix b=e(b)
			matrix V=e(V)
			scalar pvalue=(2*ttail(e(df_r), abs(el(b,1,1)/sqrt(el(V,1,1)))))
			matrix ttest_`typs'_vars_`p'=ttest_`typs'_vars_`p'\(meangroup,pvalue)		
		}
		matrix ttest_`typs'_vars_`p'=ttest_`typs'_vars_`p'[2..rowsof(ttest_`typs'_vars_`p'),.]
		matrix rownames ttest_`typs'_vars_`p'=$stat_vars
		matrix colnames ttest_`typs'_vars_`p'= Mean_all SE_all  Mean_child_wasting SE_child_wasting Mean_nonchild_wasting SE_nonchild_wasting  Pvalue

	*Wasting incidence among all, poor and non-poor households
		matrix pov_`typs'_vars_`p'=J(1,4,.)
		foreach x of global `typs'_vars {
			qui tabstat child_wasting [aw=hhweight] if HH7==`p', by(`x')   statistics (mean semean) save // to get means that reflect the survey weights
			capture confirm matrix r(Stat2)
			if _rc==0 { 
				matrix meangroup=100*r(Stat2)',100*r(Stat1)'
			}
			if _rc!=0 { 
				matrix meangroup=J(1,4,.)
			}	
			matrix pov_`typs'_vars_`p'=pov_`typs'_vars_`p'\meangroup				
		}

		matrix pov_`typs'_vars_`p'=pov_`typs'_vars_`p'[2..rowsof(pov_`typs'_vars_`p'),.]
		matrix rownames pov_`typs'_vars_`p'=$stat_vars
		matrix colnames pov_`typs'_vars_`p'= Pov_Mean_child_wasting Pov_SE_child_wasting Pov_Mean_nonchild_wasting  Pov_SE_nonchild_wasting
		matrix list pov_`typs'_vars_`p'
		matrix pov_`typs'_vars_combined_`p'=ttest_`typs'_vars_`p', J(rowsof(ttest_`typs'_vars_`p'),1,.), pov_`typs'_vars_`p'

		local m=`n'+35
		local q=`m'-2
		putexcel set "${output}/BHA_DRC_SDA Wasting Summary statistics_January_2023.xls", sheet("`typs'_vars - child_wasting") modify
		qui putexcel A`q'="Province `p'" 
		if `p'==16 {
		    qui putexcel B`q'="South Kivu" 
		}
		if `p'==21 {
		    qui putexcel B`q'="Tanganyika" 
		}
		if `p'==23 {
		    qui putexcel B`q'="Kasai Oriental" 
		}
		if `p'==25 {
		    qui putexcel B`q'="Kasai Central" 
		}
		if `p'==26 {
		    qui putexcel B`q'="Kasai" 
		}
		
		qui putexcel A`m'=matrix(pov_`typs'_vars_combined_`p') , names 
		local n=`m'+10		
	}	
}	


* OLS Regressions under five


**Children under 5 
*DRC- National
reg child_wasting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 i.stratum [aw=hhweight] 
estimates store all_hh7

* By province
reg child_wasting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 i.stratum [aw=hhweight] if  HH7==21 
estimates store all_hh7_21
reg child_wasting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 i.stratum [aw=hhweight] if  HH7==26 
estimates store all_hh7_26
reg child_wasting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 i.stratum [aw=hhweight] if  HH7==25 
estimates store all_hh7_25

coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($child_vars2) xline(0) legend(rows(1)) msymbol(D)  msize(medium) lcolor(red) coeflabels(, notick labgap(5) labsize(vlarge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(vlarge)) subtitle(,size(vlarge)) 
graph export "${output}\child_wasting_correlates_child_vars2_Province_ALL.pdf", replace

coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($childhealth_vars2) xline(0) legend(rows(1)) msymbol(D)  msize(medium) lcolor(red) coeflabels(, notick labgap(5) labsize(vlarge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(vlarge)) subtitle(,size(vlarge)) 
graph export "${output}\child_wasting_correlates_childhealth_vars2_Province_ALL.pdf", replace

 
coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($mother_vars2) xline(0)   legend(rows(1)) msymbol(s)  msize(medium) coeflabels(, notick labgap(5) labsize(vlarge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(vlarge)) subtitle(,size(vlarge))
graph export "${output}\child_wasting_correlates_mother_vars2_Province_ALL.pdf", replace


coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($hhold_vars2) xline(0)   legend(rows(1)) msymbol(s)  msize(medium) coeflabels(, notick labgap(5) labsize(vlarge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(vlarge)) subtitle(,size(vlarge)) order(2:)
graph export "${output}\child_wasting_correlates_hhold_vars2_Province_ALL.pdf", replace
 
outreg2 [all_hh7_21 all_hh7_26 all_hh7_25 all_hh7] using  "${output}\Wasting_correlates_ALL.xls", addstat(Adjusted R-squared, e(r2_a)) dec(2)  replace

**Children umder 2 
*DRC- National
reg child_wasting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 $infant_mdd_vars2 i.stratum [aw=hhweight] 
estimates store all_hh7

* By province
reg child_wasting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 $infant_mdd_vars2 i.stratum [aw=hhweight] if  HH7==21 
estimates store all_hh7_21
reg child_wasting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 $infant_mdd_vars2 i.stratum [aw=hhweight] if  HH7==26 
estimates store all_hh7_26
reg child_wasting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 $infant_mdd_vars2 i.stratum [aw=hhweight]    if  HH7==25 
estimates store all_hh7_25

coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($infant_mdd_vars2) xline(0)   legend(rows(1)) msymbol(D)  msize(medium) lcolor(red) coeflabels(, notick labgap(5) labsize(vlarge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(vlarge)) subtitle(,size(vlarge)) 
graph export "${output}\child_wasting_IYFP_correlates_infant_mdd_vars2_Province_ALL.pdf", replace
  
outreg2 [all_hh7_21 all_hh7_26 all_hh7_25 all_hh7] using  "${output}\Wasting_IYFP_correlates_ALL.xls", addstat(Adjusted R-squared, e(r2_a))  dec(2)  replace


*Stunting==================
**ALL HOUSEHOLDS
foreach typs in child mother hhold inf_mdd {
*DRC National	
	*Distribution among all, poor and non-poor households
	matrix ttest_`typs'_vars=J(1,7,.)
	global stat_vars ""
	*di "$stat_`typs'_vars"	
	foreach x of global `typs'_vars {
		qui tabstat `x' [aw=hhweight], by(child_stunting)   statistics (mean semean) save // to get means that reflect the survey weights
		matrix meangroup=100*r(StatTotal)', 100*r(Stat2)',100*r(Stat1)'
		qui reg `x' child_stunting [aw=hhweight] // to get pvalues that reflect the survey weights
		matrix b=e(b)
		matrix V=e(V)
		scalar pvalue=(2*ttail(e(df_r), abs(el(b,1,1)/sqrt(el(V,1,1)))))
		matrix ttest_`typs'_vars=ttest_`typs'_vars\(meangroup,pvalue)
		global stat_vars $stat_vars Mean_`x'  
	}


	matrix ttest_`typs'_vars=ttest_`typs'_vars[2..rowsof(ttest_`typs'_vars),.]
	matrix rownames ttest_`typs'_vars=$stat_vars
	matrix colnames ttest_`typs'_vars= Mean_all SE_all  Mean_child_stunting SE_child_stunting Mean_nonchild_stunting SE_nonchild_stunting  Pvalue 

	*Stunting incidence among all, poor and non-poor households
	matrix pov_`typs'_vars=J(1,4,.)
	foreach x of global `typs'_vars {
		qui tabstat child_stunting [aw=hhweight], by(`x')   statistics (mean semean) save // to get means that reflect the survey weights
		capture confirm matrix r(Stat2)
		if _rc==0 { 
			matrix meangroup=100*r(Stat2)',100*r(Stat1)'
		}
		if _rc!=0 { 
			matrix meangroup=J(1,4,.)
		}		
		matrix pov_`typs'_vars=pov_`typs'_vars\meangroup	
	}

	matrix pov_`typs'_vars=pov_`typs'_vars[2..rowsof(pov_`typs'_vars),.]
	matrix rownames pov_`typs'_vars=$stat_vars
	matrix colnames pov_`typs'_vars= Pov_Mean_child_stunting Pov_SE_child_stunting Pov_Mean_nonchild_stunting  Pov_SE_nonchild_stunting
	
	matrix pov_`typs'_vars_combined=ttest_`typs'_vars, J(rowsof(ttest_`typs'_vars),1,.), pov_`typs'_vars
	matrix list pov_`typs'_vars_combined
	
	putexcel set "${output}/BHA_DRC_SDA Stunting Summary statistics_November_2022.xls", sheet("`typs'_vars - child_stunting", replace) modify
	qui putexcel A2="ALL HOUSEHOLDS" 
	qui putexcel A4="Stunting Summary Statistics - `typs'_vars" 
	qui putexcel A6="DRC National" 
	qui putexcel A8 =matrix(pov_`typs'_vars_combined) , names
 
*By province
	*Distribution among all, poor and non-poor households
	local n: word count $`typs'_vars 
	di "`n'"
	foreach p of global cfocus_provinces {	
		di "`p'"
		matrix ttest_`typs'_vars_`p'=J(1,7,.)
		foreach x of global `typs'_vars {
			qui tabstat `x' [aw=hhweight] if HH7==`p', by(child_stunting)   statistics (mean semean) save // to get means that reflect the survey weights
			matrix meangroup=100*r(StatTotal)', 100*r(Stat2)',100*r(Stat1)'
			qui reg `x' child_stunting [aw=hhweight] if HH7==`p' // to get pvalues that reflect the survey weights
			matrix b=e(b)
			matrix V=e(V)
			scalar pvalue=(2*ttail(e(df_r), abs(el(b,1,1)/sqrt(el(V,1,1)))))
			matrix ttest_`typs'_vars_`p'=ttest_`typs'_vars_`p'\(meangroup,pvalue)		
		}

		matrix ttest_`typs'_vars_`p'=ttest_`typs'_vars_`p'[2..rowsof(ttest_`typs'_vars_`p'),.]
		matrix rownames ttest_`typs'_vars_`p'=$stat_vars
		matrix colnames ttest_`typs'_vars_`p'= Mean_all SE_all  Mean_child_stunting SE_child_stunting Mean_nonchild_stunting SE_nonchild_stunting  Pvalue

	*Stunting incidence among all, poor and non-poor households
		matrix pov_`typs'_vars_`p'=J(1,4,.)
		foreach x of global `typs'_vars {
			qui tabstat child_stunting [aw=hhweight] if HH7==`p', by(`x')   statistics (mean semean) save // to get means that reflect the survey weights
			capture confirm matrix r(Stat2)
			if _rc==0 { 
				matrix meangroup=100*r(Stat2)',100*r(Stat1)'
			}
			if _rc!=0 { 
				matrix meangroup=J(1,4,.)
			}	
			matrix pov_`typs'_vars_`p'=pov_`typs'_vars_`p'\meangroup				
		}

		matrix pov_`typs'_vars_`p'=pov_`typs'_vars_`p'[2..rowsof(pov_`typs'_vars_`p'),.]
		matrix rownames pov_`typs'_vars_`p'=$stat_vars
		matrix colnames pov_`typs'_vars_`p'= Pov_Mean_child_stunting Pov_SE_child_stunting Pov_Mean_nonchild_stunting  Pov_SE_nonchild_stunting
		matrix list pov_`typs'_vars_`p'
		matrix pov_`typs'_vars_combined_`p'=ttest_`typs'_vars_`p', J(rowsof(ttest_`typs'_vars_`p'),1,.), pov_`typs'_vars_`p'

		local m=`n'+35
		local q=`m'-2
		putexcel set "${output}/BHA_DRC_SDA Stunting Summary statistics_November_2022.xls", sheet("`typs'_vars - child_stunting") modify
		qui putexcel A`q'="Province `p'" 
		if `p'==16 {
		    qui putexcel B`q'="South Kivu" 
		}
		if `p'==21 {
		    qui putexcel B`q'="Tanganyika" 
		}
		if `p'==23 {
		    qui putexcel B`q'="Kasai Oriental" 
		}
		if `p'==25 {
		    qui putexcel B`q'="Kasai Central" 
		}
		if `p'==26 {
		    qui putexcel B`q'="Kasai" 
		}
		
		qui putexcel A`m'=matrix(pov_`typs'_vars_combined_`p') , names 
		local n=`m'+10		
	}	
}	


* OLS Regressions under five

**Children under 5 
*DRC- National
reg child_stunting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 i.stratum [aw=hhweight] 
estimates store all_hh7

* By province
reg child_stunting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 i.stratum [aw=hhweight] if  HH7==21 
estimates store all_hh7_21
reg child_stunting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 i.stratum [aw=hhweight] if  HH7==26 
estimates store all_hh7_26
reg child_stunting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 i.stratum [aw=hhweight] if  HH7==25 
estimates store all_hh7_25

coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($child_vars2) xline(0) legend(rows(1)) msymbol(D)  msize(medium) lcolor(red) coeflabels(, notick labgap(5) labsize(vlarge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(vlarge)) subtitle(,size(vlarge)) 
graph export "${output}\child_stunting_correlates_child_vars2_Province_ALL.pdf", replace

coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($childhealth_vars2) xline(0) legend(rows(1)) msymbol(D)  msize(medium) lcolor(red) coeflabels(, notick labgap(5) labsize(vlarge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(vlarge)) subtitle(,size(vlarge)) 
graph export "${output}\child_stunting_correlates_childhealth_vars2_Province_ALL.pdf", replace

 
coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($mother_vars2) xline(0)   legend(rows(1)) msymbol(s)  msize(medium) coeflabels(, notick labgap(5) labsize(vlarge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(vlarge)) subtitle(,size(vlarge))
graph export "${output}\child_stunting_correlates_mother_vars2_Province_ALL.pdf", replace


coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($hhold_vars2) xline(0)   legend(rows(1)) msymbol(s)  msize(medium) coeflabels(, notick labgap(5) labsize(vlarge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(vlarge)) subtitle(,size(vlarge)) order(2:)
graph export "${output}\child_stunting_correlates_hhold_vars2_Province_ALL.pdf", replace
 
outreg2 [all_hh7_21 all_hh7_26 all_hh7_25 all_hh7] using  "${output}\stunting_correlates_ALL.xls", addstat(Adjusted R-squared, e(r2_a)) dec(2)  replace label



**Children umder 2 
*DRC- National
reg child_stunting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 $infant_mdd_vars2 i.stratum [aw=hhweight] 
estimates store all_hh7

* By province
reg child_stunting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 $infant_mdd_vars2 i.stratum [aw=hhweight] if  HH7==21 
estimates store all_hh7_21
reg child_stunting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 $infant_mdd_vars2 i.stratum [aw=hhweight] if  HH7==26 
estimates store all_hh7_26
reg child_stunting $child_vars2 $childhealth_vars2 $mother_vars2 $hhold_vars2 $infant_mdd_vars2 i.stratum [aw=hhweight]    if  HH7==25 
estimates store all_hh7_25

coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($infant_mdd_vars2) xline(0)   legend(rows(1)) msymbol(D)  msize(medium) lcolor(red) coeflabels(, notick labgap(5) labsize(vlarge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(vlarge)) subtitle(,size(vlarge)) 
graph export "${output}\child_stunting_IYFP_correlates_infant_mdd_vars2_Province_ALL.pdf", replace

  
outreg2 [all_hh7_21 all_hh7_26 all_hh7_25 all_hh7] using  "${output}\stunting_IYFP_correlates_ALL.xls", addstat(Adjusted R-squared, e(r2_a))  dec(2)  replace label
