/*---------------------------------------------------------------------------------------------------

Project Name
**************************
 
POVERTY AND MALNUTRITION IN THE DEMOCRATIC REPUBLIC OF THE CONGO: 
SECONDARY DATA ANALYSIS FINDINGS FROM THE PROVINCES OF TANGANYIKA, KASAI, AND KASAI CENTRAL
 
LASER PULSE
Long-term Assistance and SErvices for Research (LASER)
Partners for University-Led Solutions Engine (PULSE)

Data: MICS6 2017-2018, DRC
Poverty analyses

SUGGESTED CITATION
Alia, D., Kibriya, S., Connaughton, S. L., Fatema, N., Sagbo, S., and Kasa, L. 2023. Poverty and
Malnutrition in the Democratic Republic of the Congo (DRC): Secondary Data Analysis (SDA)
Findings from the Provinces of Tanganyika, Kasai, and Kasai Central. West Lafayette, IN: Long-
term Assistance and Services for Research - Partners for University-Led Solutions Engine
(LASER PULSE Consortium).
  
Created: August 20, 2022

---------------------------------------------------------------------------------------------------*/
 
 
*## Set paths for directories and files
global path 			"C:\Users\dyali\OneDrive\BHA_DRC_SDA"
global path 			"C:\Users\dyalia\dyalia_OneDrive\OneDrive\BHA_DRC_SDA"

global raw_data 		"${path}/Raw_data/DRCongo MICS6 SPSS Datafiles/Stata"
global created_data 	"${path}/Created_data"
global output		 	"${path}/Output"

*## Create the excel file where the estimates will be outputted
clear matrix
putexcel set "${output}/BHA_DRC_SDA Poverty 20 Percent Summary statistics_January_2023.xls", replace

*## Uncomment and run the following four lines of code once if the commands are not yet installed
*ssc install matodd
*ssc install matewd
*ssc install coefplot 
*ssc install outreg2
*ssc install estout

/*
Please register with the MICS team to obtain access to the raw data.
These data come as spss (.sav) file. They can be first converted to stata (.dta) files
by opening the spss file (with SPSS) and then by clicking 'save as' and choosing 'stata' as the file type.
The stata file must saved in the folder referenced in the path "${raw_data}"
*/


//============================================================================//
//																	          //
//									Household Poverty						  //
//																			  //
//============================================================================//

*## Tag the focus provinces for the analysis
global focus_provinces "21, 25, 26"  //16-South Kivu, 21-Tanganyika, 23-Kasai Oriental, 25-Kasai Central, and 26-Kasai
global cfocus_provinces "21 25 26"  //16-South Kivu, 21-Tanganyika, 23-Kasai Oriental, 25-Kasai Central, and 26-Kasai
global nfocus_provinces "Tanganyika Kasai_Central Kasai"

*## Raw data on households
use "${raw_data}/hh.dta", clear

*## Checking that this file is at the household level and has not dupplicates
duplicates report HH1 HH2  // 20,810 unique observations with no dupplicates

*## Checking the labels for provinces
label list HH7
drop if windex5==0  // there 18 households for which we do not have wealth index because these households did not complete the survey. We are excluding them from the analysis


*## Table 1: Sample size
tab HH7 if inlist(HH7,${focus_provinces}), matcell(sample_hh) 
count
matrix sample_hh=sample_hh\r(N)
matrix rownames sample_hh=${nfocus_provinces} DRC_national
matrix colnames sample_hh=Sample_hh
matrix list sample_hh


*## Distribution of wealth score
**********************************************************
		
*## Kernel density estimation / Figure 1: Distribution of household wealth index by province
capture drop auxx 
capture drop den*
qui sum wscore, detail
gen auxx=.
replace auxx=_n*(r(p99)-r(p1))/100+r(p1) in 1/100

qui kdensity wscore, nograph at(auxx)
local h=r(bwidth)

** National
kdensity wscore /*[fw=hhweight]*/, nograph generate(aux denall) at(auxx)  bwidth(`h')
drop aux
lab var denall "All HHs"
kdensity wscore if  HH6==2 /*[fw=hhweight]*/, nograph generate(aux denrur) at(auxx)  bwidth(`h')
drop aux
lab var denrur "Rural HHs"
kdensity wscore if HH6==1 /*[fw=hhweight]*/, nograph generate(aux denurb) at(auxx)  bwidth(`h')
drop aux
lab var denurb "Urban HHs"
twoway (line denall auxx, sort lwidth(medthick) lpattern(dash)) ///
	   (line denrur auxx, sort lwidth(medthick) lpattern(shortdash)) ///
	   (line denurb auxx, sort lwidth(medthick) lpattern(shortdash)) ///
	   ,xti("")  ytitle("Estimated density" " ",size(large))  xtitle("Wealth index score" " ",size(large)) ///
	   xlab(, labsize(large)) ylab(,labsize(large)) title("DRC National") name(kds_DRCnational, replace)  legend(rows(1)  keygap(0.7))
	   	   
*By provinces	
local n16 "South Kivu"	
local n21 "Tanganyika"	
local n23 "Kasai Oriental"	
local n25 "Kasai Central"	
local n26 "Kasai"	

*global cfocus_provinces 25 
foreach p of global cfocus_provinces {
	capture drop auxx 
	capture drop den*
	qui sum wscore, detail
	gen auxx=.
	replace auxx=_n*(r(p99)-r(p1))/100+r(p1) in 1/100

	qui kdensity wscore, nograph at(auxx)
	local h=r(bwidth)

	** National
	kdensity wscore /*[fw=hhweight]*/ if HH7==`p', nograph generate(aux denall) at(auxx)  bwidth(`h')
	drop aux
	lab var denall "All HHs"
	kdensity wscore if  HH6==2 & HH7==`p' /*[fw=hhweight]*/, nograph generate(aux denrur) at(auxx)  bwidth(`h')
	drop aux
	lab var denrur "Rural HHs"
	kdensity wscore if HH6==1 & HH7==`p' /*[fw=hhweight]*/, nograph generate(aux denurb) at(auxx)  bwidth(`h')
	drop aux
	lab var denurb "Urban HHs"
	twoway (line denall auxx, sort lwidth(medthick) lpattern(dash)) ///
		   (line denrur auxx, sort lwidth(medthick) lpattern(shortdash)) ///
		   (line denurb auxx, sort lwidth(medthick) lpattern(shortdash)) ///
	   ,xti("")  ytitle("Estimated density" " ",size(large))  xtitle("Wealth index score" " ",size(large)) ///
	   xlab(, labsize(large)) ylab(,labsize(large))  title("`n`p''")  name(kds_`p', replace)  legend(rows(1)  keygap(0.7))
 
}


*## Figure 2: Prevalence of poverty by province

***Poverty summary statistics
gen poor20=windex5==1
lab var poor20 "1= Households is poor, bottom 20 percenting of wealth national distribution"
gen poor40=windex5==1 | windex5==2
lab var poor40 "1= Households is poor, bottom 40 percenting of wealth national distribution"

*by province
preserve
keep if inlist(HH7,${focus_provinces}) 
collapse (mean) poor20 [aw=hhweight], by(HH7)
gen HH6=0
tempfile poor20_all
save `poor20_all'
restore

preserve
keep if inlist(HH7,${focus_provinces}) 
collapse (mean) poor20 [aw=hhweight], by(HH7 HH6)
recode HH6 (2=1) (1=2)
tempfile poor20_by_HH6
save `poor20_by_HH6'
restore

*National
preserve
collapse (mean) poor20 [aw=hhweight]
gen HH6=0
gen HH7=1000 //DRC nationa
tempfile poor20_all_nat
save `poor20_all_nat'
restore

preserve
collapse (mean) poor20 [aw=hhweight], by(HH6)
recode HH6 (2=1) (1=2)
gen HH7=1000 //DRC national
tempfile poor20_by_HH6_nat
save `poor20_by_HH6_nat'
restore

preserve
use  `poor20_all', clear
append using `poor20_by_HH6'
append using `poor20_all_nat'
append using `poor20_by_HH6_nat'
label define HH7 1000  "DRC National", modify
replace poor20=poor20*100
gen labpoor20=poor20
export excel using "${output}\BHA_DRC_SDA Summary statistics - poverty_January_2022.xls", replace
graph bar poor20 , over(HH6) over(HH7, label(angle(25))) asyvars blabel(labpoor20) legend(rows(1))  ///
legend( order(1 "All HHs" 2 "Rural HHs" 3 "Urban HHs") ) ytitle("Percent of households that are poor (%)" " ")
graph export "${output}\Poor20_percent.pdf", replace
restore


*## Figure 3: Percentage of households by wealth quintile and province
*## Figure A1: Difference in the distribution of household wealth quintile between rural and urban households by province.

*## DRC National - All
ta windex5  [aw=hhweight],   nofreq matcell(dist_wealth_all) 
mata : st_matrix("sdist_wealth_all", colsum(st_matrix("dist_wealth_all")))  // get the total for each column to compute percentages
forval i = 1/`= rowsof(dist_wealth_all)' { 
 	mat ssdist_wealth_all = nullmat(ssdist_wealth_all) \ el(sdist_wealth_all,1,1)
}
matewd dist_wealth_all ssdist_wealth_all DRC_dist_wealth_all

*## DRC National - Rural
ta windex5  [aw=hhweight] if HH6==2,   nofreq matcell(dist_wealth_rural) 
mata : st_matrix("sdist_wealth_rural", colsum(st_matrix("dist_wealth_rural")))  // get the total for each column to compute percentages
forval i = 1/`= rowsof(dist_wealth_rural)' { 
 	mat ssdist_wealth_rural = nullmat(ssdist_wealth_rural) \ el(sdist_wealth_rural,1,1)
}
matewd dist_wealth_rural ssdist_wealth_rural DRC_dist_wealth_rural

*## DRC National - Urban
ta windex5  [aw=hhweight] if HH6==1,   nofreq matcell(dist_wealth_urban) 
mata : st_matrix("sdist_wealth_urban", colsum(st_matrix("dist_wealth_urban")))  // get the total for each column to compute percentages
forval i = 1/`= rowsof(dist_wealth_urban)' { 
 	mat ssdist_wealth_urban = nullmat(ssdist_wealth_urban) \ el(sdist_wealth_urban,1,1)
}
matewd dist_wealth_urban ssdist_wealth_urban DRC_dist_wealth_urban

*## DRC National - combined
matrix dist_wealth_combined=DRC_dist_wealth_all',J(1,2,.),DRC_dist_wealth_rural',J(1,2,.),DRC_dist_wealth_urban'
matrix list dist_wealth_combined


*## By province - All
ta windex5 HH7 [aw=hhweight] if inlist(HH7,${focus_provinces}), col nofreq matcell(Pdist_wealth_all)  // All households
mata : st_matrix("sPdist_wealth_all", colsum(st_matrix("Pdist_wealth_all")))  // get the total for each column to compute percentages
forval i = 1/`= rowsof(Pdist_wealth_all)' { 
 	mat ssPdist_wealth_all = nullmat(ssPdist_wealth_all) \ sPdist_wealth_all 
}
matewd Pdist_wealth_all ssPdist_wealth_all Pdist_wealth_all
matrix Pdist_wealth_all=Pdist_wealth_all
matrix colnames Pdist_wealth_all= ${nfocus_provinces}
matrix rownames Pdist_wealth_all=1Quartile 2Quartile 3Quartile 4Quartile 5Quartile
matrix list Pdist_wealth_all

*## By province - Rural
ta windex5 HH7 [aw=hhweight] if inlist(HH7,${focus_provinces}) & HH6==2, col nofreq matcell(Pdist_wealth_rural)  // rural households
mata : st_matrix("sPdist_wealth_rural", colsum(st_matrix("Pdist_wealth_rural")))  // get the total for each column to compute percentages
forval i = 1/`= rowsof(Pdist_wealth_rural)' { 
 	mat ssPdist_wealth_rural = nullmat(ssPdist_wealth_rural) \ sPdist_wealth_rural 
}
matewd Pdist_wealth_rural ssPdist_wealth_rural Pdist_wealth_rural
matrix colnames Pdist_wealth_rural= ${nfocus_provinces}
matrix Pdist_wealth_rural=Pdist_wealth_rural\J(1,colsof(Pdist_wealth_rural),0)  // adding a row of 0 because no rural hh falls in the fifth quartile
matrix rownames Pdist_wealth_rural=1Quartile 2Quartile 3Quartile 4Quartile 5Quartile
matrix list Pdist_wealth_rural

*## By province - Urban
ta windex5 HH7 [aw=hhweight] if inlist(HH7,${focus_provinces}) & HH6==1, col nofreq matcell(Pdist_wealth_urban)  // urban households
mata : st_matrix("sPdist_wealth_urban", colsum(st_matrix("Pdist_wealth_urban")))  // get the total for each column to compute percentages
forval i = 1/`= rowsof(Pdist_wealth_urban)' { 
 	mat ssPdist_wealth_urban = nullmat(ssPdist_wealth_urban) \ sPdist_wealth_urban 
}
matewd Pdist_wealth_urban ssPdist_wealth_urban Pdist_wealth_urban
matrix colnames Pdist_wealth_urban= ${nfocus_provinces}
matrix rownames Pdist_wealth_urban=1Quartile 2Quartile 3Quartile 4Quartile 5Quartile
matrix list Pdist_wealth_urban

*## By province - combined
matrix Pdist_wealth_combined=Pdist_wealth_all',J(3,2,.),Pdist_wealth_rural',J(3,2,.),Pdist_wealth_urban'
matrix list Pdist_wealth_combined

*## DRC and by province - combined
matrix dist_wealth_combined= Pdist_wealth_combined\dist_wealth_combined
matrix rownames dist_wealth_combined= ${nfocus_provinces} DRC_National
matrix list dist_wealth_combined

*## Export DRC National estimates of wealth quintiles to excel
putexcel set "${output}/BHA_DRC_SDA Poverty 20 Percent Summary statistics_January_2023.xls", sheet("dist_wealth_combined", replace) replace
qui putexcel A1="Distribution of household by wealth quintile" 
qui putexcel A5 =matrix(dist_wealth_combined) , names
	
	
	
	
*## Creating relevant variables
**********************************************************
gen number_rooms=HC3
ren HC4 floor_material
gen floor_material_sand=floor_material==11
gen floor_material_cement=floor_material==34 | floor_material==33
gen floor_material_ceramic=floor_material==33
gen floor_material_others=inlist(floor_material,12,21,22,31,32,35,96)

ren HC5 rool_material
gen rool_material_plalmleaf=inlist(rool_material,12,22)
gen rool_material_weeds=inlist(rool_material,13,21)
gen rool_material_metal=inlist(rool_material,31)
gen rool_material_others=inlist(rool_material,23,24,32,33,34,35,36,96)

ren HC6	wall_material
gen wall_material_brick =inlist(wall_material,31,32,33,34)
gen wall_material_mud =inlist(wall_material,13,21,22,23,35)
gen wall_material_wood =inlist(wall_material,12,24,25,26,36)
gen wall_material_others =inlist(wall_material,27,96)

gen phone=inlist(HC7A,1) | inlist(HC12,1)
gen radio=inlist(HC7B,1)
gen lamppetro=inlist(HC7C,1)
gen watch=inlist(HC7D,1) | inlist(HC10A,1)
gen bedframe=inlist(HC7E,1)
gen table=inlist(HC7F,1)
gen chairs=inlist(HC7G,1)
gen couch=inlist(HC7H,1)
gen dresser=inlist(HC7I,1)
gen eletricity=inlist(HC8,1,2)
gen television=inlist(HC9A,1)
gen refrigerator=inlist(HC9B,1)
gen stove=inlist(HC9C,1)
gen washer_machine=inlist(HC9D,1)
gen iron=inlist(HC9E,1)
gen fan=inlist(HC9F,1)
gen water_heater=inlist(HC9G,1)
gen microwave=inlist(HC9H,1)
gen dvd_player=inlist(HC9I,1) 
gen AC=inlist(HC9J,1)

gen bicycle=inlist(HC10B,1)
gen motorbike=inlist(HC10C,1)
gen plow=inlist(HC10D,1)
gen car=inlist(HC10E,1)
gen boat=HC10F==1 | HC10G==1 | HC10H==1
gen computer=inlist(HC11,1)
gen internet=inlist(HC13,1)
gen house=HC14==1
gen agland= inlist(HC15,1)
gen farmsize=HC16
recode farmsize (.=0) (95=95) (98 99=.)
gen lruminant_cattle=inrange(HC18A,1,95)
gen nb_cattle=HC18A 
recode nb_cattle (.=0) (95=95) (98 99=.)
gen lruminant_other_cattle=inrange(HC18B,1,95)
gen lruminant_others=inrange(HC18C,1,95)
gen poultry =inrange(HC18F,1,95) 
gen nb_poultry=HC18F
recode nb_poultry  (.=0) (95=95) (98 99=.)
gen sruminant_shoagts=inrange(HC18D, 1, 95) | inrange(HC18E, 1, 95)
recode HC18D HC18E  (.=0) (95=95) (98 99=.)
egen nb_shoats=rowtotal(HC18D HC18E)
gen sruminant_pigs=inrange(HC18G, 1, 95)  
gen nb_pigs=HC18G
recode nb_pigs  (.=0) (95=95) (98 99=.)
gen sruminant_rabits=inrange(HC18H, 1, 95)  | inrange(HC18I, 1, 95)
gen bank_account=inlist(HC19,1)
gen cook_charcoal=inlist(EU4,5)
gen cook_woods=inlist(EU4,6,7,11)
gen cook_other=inlist(EU4,2,3,4,8,9,10,96)

gen cookplace_inhouse =inlist(EU5,1,2)
gen cookplace_sephouse=inlist(EU5,3)
gen cookplace_outdoor=inlist(EU5,4,5,6)

gen bednet=inlist(TN1,1)
gen drinkwater_safe=inlist(WS1,11,12,13,14,21,31,41,61,62,72,91)
gen drinkwater_unsafe=inlist(WS1,32,51,81,96)

gen toilet_modern=inlist(WS11,11,12,13,14,18)
gen toilet_tradisafe=inlist(WS11,21,22,23,31,41,51)
gen toilet_opendef=inlist(WS11,95,96)

gen water_to_washang=inlist(HW2,1)

gen hh_female=hhsex==2
gen hh_age=hhage
gen hh_noschool=inlist(helevel,0)
gen hh_primary=inlist(helevel,1)
gen hh_secondary=inlist(helevel,2,3)
gen hh_tertiary=inlist(helevel,4)

gen hh_rural=inlist(HH6,2)
gen hh_size=HH48
gen hh_children_5=HH51
gen hh_children_5_17=HH52

gen table_chairs=table==1 | chairs==1
gen motorvehicle=motorbike==1 | car==1 

gen radio_tv_dvd=radio==1 | television==1 | dvd_player==1  
gen table_chairs_couch_dresser=table==1 | chairs==1 | couch==1 | dresser==1
gen cookplace_closedspace =cookplace_inhouse==1 | cookplace_sephouse
gen cook_woodsproduct=inlist(EU4,5,6,7,9,11)
gen hh_secondaryplus=hh_secondary==1 | hh_tertiary==1


*Regroupping some variables for the regression
gen floor_material_precarous=!(floor_material_cement==1 | floor_material_ceramic==1)
gen rool_material_precarous=!(inlist (rool_material,31,32,33,34,35,36))
gen wall_material_precarous=!(inlist (wall_material,26,27,31,32,33,34,35,36))


global house_vars house number_rooms floor_material_sand floor_material_cement /*floor_material_ceramic*/ /*
*/ /*floor_material_others*/ rool_material_metal rool_material_plalmleaf rool_material_weeds /*rool_material_others*/ /*
*/ wall_material_brick wall_material_mud  wall_material_wood /*wall_material_others*/ 

global oths_vars table_chairs couch bedframe dresser  bicycle motorvehicle boat /*watch*/ radio television /*dvd_player*/ computer phone 
 /*washer_machine iron fan AC */

global ag_vars agland farmsize lruminant_cattle nb_cattle /*lruminant_other_cattle lruminant_others*/ /*
*/ sruminant_shoagts nb_shoats sruminant_pigs nb_pigs poultry nb_poultry sruminant_rabits plow     

global washh_vars lamppetro /*stove refrigerator*/ /*
*/ cookplace_inhouse cookplace_sephouse cookplace_outdoor  cook_charcoal cook_woods /*cook_other*/ drinkwater_safe  drinkwater_unsafe /*
*/ toilet_modern toilet_tradisafe toilet_opendef water_to_washang bednet 

global demog_vars hh_rural hh_female hh_size hh_children_5 hh_children_5_17 hh_age /*
*/ hh_noschool hh_primary hh_secondary hh_tertiary  eletricity internet bank_account   


*labelling all variables for the codebook
lab var  hh_rural  "HH is rural"
lab var  hh_female  "Head of HH is female"
lab var  hh_size  "HH size"
lab var  hh_children_5  "Number children under 5"
lab var  hh_children_5_17  "Number children aged 5-17"
lab var  hh_age  "Head of HH age"
lab var  hh_noschool  "Head of HH: no schooling"
lab var  hh_primary  "Head of HH: Primary school"
lab var  hh_secondary  "Head of HH: Secondary school"
lab var  hh_tertiary  "Head of HH: Tertiary school"
lab var  eletricity  "Has electricity"
lab var  internet  "Has internet"
lab var  bank_account  "Has a bank account"
lab var	house	"House ownership"
lab var	number_rooms	"Number of rooms"
lab var	floor_material_sand	"Floor materials: Sand"
lab var	floor_material_cement	"Floor materials: Cement"
lab var	rool_material_metal	"Roof materials: Metal"
lab var	rool_material_plalmleaf	"TRoof materials: Leaves"
lab var	rool_material_weeds	"Roof materials: Weeds and others"
lab var	wall_material_brick	"Wall materials: Bricks"
lab var	wall_material_mud	"Wall materials: Mud"
lab var	wall_material_wood	"Wall materials: Woods"
lab var	lamppetro	"Use pretrolum lamp"
lab var	cookplace_inhouse	"Cooking place: In-house"
lab var	cookplace_sephouse	"Cooking place: Separate house"
lab var	cookplace_outdoor	"Cooking place: Outdoor"
lab var	cook_charcoal	"Cooking fuel: Charcoal"
lab var	cook_woods	"Cooking fuel: Woods, others"
lab var	drinkwater_safe	"Drinking water source: Safe"
lab var	drinkwater_unsafe	"Drinking water source: Unsafe"
lab var	toilet_modern	"Type of toilet: Modern"
lab var	toilet_tradisafe	"Type of toilet: Traditional"
lab var	toilet_opendef	"Type of toilet: Open defecation"
lab var	water_to_washang	"Water to wash hand"
lab var	bednet	"Has bednet"
lab var  agland  "Owns an agricultural land"
lab var  farmsize  "Farm size"
lab var  lruminant_cattle  "Owns cattle"
lab var  nb_cattle  "Number of cattle"
lab var  sruminant_shoagts  "Owns sheep and goats"
lab var  nb_shoats  "Number of sheep and goats"
lab var  sruminant_pigs  "Owns pigs"
lab var  nb_pigs  "Number of pigs"
lab var  poultry  "Owns poultry"
lab var  nb_poultry  "Number of poultry"
lab var  sruminant_rabits  "Owns rabits"
lab var	plow	"Owns a plow"
lab var	table_chairs	"Owns a table or chair"
lab var	couch	"Owns a couch"
lab var	bedframe	"Owns a bedframe/mattress"
lab var	dresser	"Owns a dresser"
lab var	bicycle	"Owns a bicycle"
lab var  motorvehicle  "Owns a motorbike or car"
lab var  boat  "Owns a boat or canoe"
lab var  radio  "Owns a radio receptor"
lab var  television  "Owns a TV"
lab var	computer	"Owns a computer"
lab var	phone	"Owns a phone"
lab var	 radio_tv_dvd "Owns radio/TV/DVD"  
lab var	 table_chairs_couch_dresser "Owns tables or chairs"
lab var	 cookplace_closedspace "Cooking place: Own or separate house"
lab var	 hh_secondaryplus "Head of HH: Secondary+ school"
lab var  floor_material_precarous  "Floor material: Precarous"
lab var  rool_material_precarous  "Roof material: Precarous"
lab var  wall_material_precarous  "Wall material: Precarous"
lab var cook_woodsproduct "Cooking fuel: Wood products"


lab var HH1  "Enumeration area"
lab var HH2  "Household ID"
lab var HH3  "Enumerator ID"
lab var HH6  "Place of residence"
lab var HH7  "Province"
lab var HH48  "Household size"
lab var HH51  "Number children under 5"
lab var HH52  "Number children aged 5-17"
lab var HC7A  "Phone"
lab var HC7B  "Radio"
lab var HC7C  "Petroleum lamp"
lab var HC7D  "Watch"
lab var HC7E  "Bed"
lab var HC7F  "Table"
lab var HC7G  "Chair"
lab var HC7H  "Couch"
lab var HC7I  "Dresser"
lab var HC8  "Elecricity"
lab var HC9A  "TV"
lab var HC9B  "Fridge"
lab var HC9C  "Closet"
lab var HC9D  "Washer machine"
lab var HC9E  "Iron"
lab var HC9F  "Fan"
lab var HC9G  "Water heater"
lab var HC9H  "Microwave"
lab var HC9I  "DVD"
lab var HC9J  "Air conditioner"
lab var HC10A  "Watch"
lab var HC10B  "Bicycle"
lab var HC10C  "Motorcycle"
lab var HC10D  "Plow"
lab var HC10E  "Car"
lab var HC10F  "Boat"
lab var HC10G  "Canoe"
lab var HC10H  "Canoe"
lab var HC11  "Computer"
lab var HC12  "Mobile phone"
lab var HC13  "Internet"
lab var HC14  "Owns the house"
lab var HC15  "Agricultural land"
lab var HC16  "Farm size"
lab var HC18A  "Cattle"
lab var HC18B  "Other large ruminants"
lab var HC18C  "Horse/Donkey"
lab var HC18D  "Sheep"
lab var HC18E  "Goat"
lab var HC18F  "Poultry"
lab var HC18G  "Pig"
lab var HC18H  "Rabit"
lab var HC18I  "Guinea pig"
lab var HC19  "Bank account"
lab var EU4  "Cooking fuel"
lab var EU5  "Cooking place"
lab var TN1  "Bednet"
lab var WS1  "Drinking water source"
lab var WS11  "Type of toilet"
lab var HW2  "Hand washing system"
lab var hhweight  "Survey weight"
lab var windex5  "Wealth quintile"
lab var stratum  "Stratum"
 
keep $demog_vars $house_vars $washh_vars $ag_vars $oths_vars hhweight stratum poor20 poor40 /*
*/ hhweight *_material_precarous radio_tv_dvd table_chairs_couch_dresser /*
*/ cookplace_closedspace hh_secondaryplus cook_woodsproduct /*
*/ HH1 HH2 HH3 HH6 HH7 windex5 hhweight stratum HC7A HC7B HC7C HC7D HC7E /*
*/ HC7F HC7G HC7H HC7I HC8 HC9A HC9B  HC9C HC9D HC9E HC9F HC9G HC9H HC9I HC9J /*
*/ HC10A HC10B HC10C HC10D HC10E HC10F HC10G HC10H HC11 HC12 HC13 HC14 HC15  /*
*/ HC16 HC18A HC18B HC18C HC18D HC18E HC18F HC18G HC18H HC18I HC19 EU4 EU5  /*
*/ TN1 WS1 WS11	HW2	HH48 HH51 HH52

quietly {
    log using "C:\Users\dyalia\dyalia_OneDrive\OneDrive\BHA_DRC_SDA\codebook_household_poverty.txt", text replace
    noisily codebook, c
    log close
}
save "${raw_data}/household_poverty.dta", replace 



*## ANALYSIS USING THE BOTTOM 20 PERCENT AS DEFINITION OF POVERTY
*=================================================================
use "${raw_data}/household_poverty.dta", clear

*## Table A1 to A5 (A1-demog, A2-house, A3-washh, A4-ag, A5-oths)


**ALL HOUSEHOLDS
foreach typs in  demog house washh ag oths    {
*DRC National	
	*Distribution among all, poor and non-poor households
	matrix ttest_`typs'_vars=J(1,7,.)
	global stat_vars ""
	*di "$stat_`typs'_vars"	
	foreach x of global `typs'_vars {
		qui tabstat `x' [aw=hhweight], by(poor20)   statistics (mean semean) save // to get means that reflect the survey weights
		matrix meangroup=100*r(StatTotal)', 100*r(Stat2)',100*r(Stat1)'
		qui reg `x' poor20 [aw=hhweight] // to get pvalues that reflect the survey weights
		matrix b=e(b)
		matrix V=e(V)
		scalar pvalue=(2*ttail(e(df_r), abs(el(b,1,1)/sqrt(el(V,1,1)))))
		matrix ttest_`typs'_vars=ttest_`typs'_vars\(meangroup,pvalue)
		global stat_vars $stat_vars Mean_`x'  
	}
 

	matrix ttest_`typs'_vars=ttest_`typs'_vars[2..rowsof(ttest_`typs'_vars),.]
	matrix rownames ttest_`typs'_vars=$stat_vars
	matrix colnames ttest_`typs'_vars= Mean_all SE_all  Mean_poor20 SE_poor20 Mean_nonpoor20 SE_nonpoor20  Pvalue 

	*Poverty incidence among all, poor and non-poor households
	matrix pov_`typs'_vars=J(1,4,.)
	foreach x of global `typs'_vars {
		qui tabstat poor20 [aw=hhweight], by(`x')   statistics (mean semean) save // to get means that reflect the survey weights
		capture confirm matrix r(Stat2)
		if _rc==0 { 
			matrix meangroup=100*r(Stat2)',100*r(Stat1)'
		}
		if _rc!=0 { 
			matrix meangroup=J(1,4,.)
		}		
		matrix pov_`typs'_vars=pov_`typs'_vars\meangroup	
	}

	matrix pov_`typs'_vars=pov_`typs'_vars[2..rowsof(pov_`typs'_vars),.]
	matrix rownames pov_`typs'_vars=$stat_vars
	matrix colnames pov_`typs'_vars= Pov_Mean_poor20 Pov_SE_poor20 Pov_Mean_nonpoor20  Pov_SE_nonpoor20
	
	matrix pov_`typs'_vars_combined=ttest_`typs'_vars, J(rowsof(ttest_`typs'_vars),1,.), pov_`typs'_vars
	matrix list pov_`typs'_vars_combined
	
	putexcel set "${output}/BHA_DRC_SDA Poverty 20 Percent Summary statistics_January_2023.xls", sheet("`typs'_vars - Poor20", replace) modify
	qui putexcel A2="ALL HOUSEHOLDS" 
	qui putexcel A4="Poverty Summary Statistics - `typs'_vars" 
	qui putexcel A6="DRC National" 
	qui putexcel A8 =matrix(pov_`typs'_vars_combined) , names
 
*By province
	*Distribution among all, poor and non-poor households
	local n: word count $`typs'_vars 
	di "`n'"
	foreach p of global cfocus_provinces {	
		di "`p'"
		matrix ttest_`typs'_vars_`p'=J(1,7,.)
		foreach x of global `typs'_vars {
			qui tabstat `x' [aw=hhweight] if HH7==`p', by(poor20)   statistics (mean semean) save // to get means that reflect the survey weights
			matrix meangroup=100*r(StatTotal)', 100*r(Stat2)',100*r(Stat1)'
			qui reg `x' poor20 [aw=hhweight] if HH7==`p' // to get pvalues that reflect the survey weights
			matrix b=e(b)
			matrix V=e(V)
			scalar pvalue=(2*ttail(e(df_r), abs(el(b,1,1)/sqrt(el(V,1,1)))))
			matrix ttest_`typs'_vars_`p'=ttest_`typs'_vars_`p'\(meangroup,pvalue)		
		}

		matrix ttest_`typs'_vars_`p'=ttest_`typs'_vars_`p'[2..rowsof(ttest_`typs'_vars_`p'),.]
		matrix rownames ttest_`typs'_vars_`p'=$stat_vars
		matrix colnames ttest_`typs'_vars_`p'= Mean_all SE_all  Mean_poor20 SE_poor20 Mean_nonpoor20 SE_nonpoor20  Pvalue

	*Poverty incidence among all, poor and non-poor households
		matrix pov_`typs'_vars_`p'=J(1,4,.)
		foreach x of global `typs'_vars {
			qui tabstat poor20 [aw=hhweight] if HH7==`p', by(`x')   statistics (mean semean) save // to get means that reflect the survey weights
			capture confirm matrix r(Stat2)
			if _rc==0 { 
				matrix meangroup=100*r(Stat2)',100*r(Stat1)'
			}
			if _rc!=0 { 
				matrix meangroup=J(1,4,.)
			}	
			matrix pov_`typs'_vars_`p'=pov_`typs'_vars_`p'\meangroup				
		}

		matrix pov_`typs'_vars_`p'=pov_`typs'_vars_`p'[2..rowsof(pov_`typs'_vars_`p'),.]
		matrix rownames pov_`typs'_vars_`p'=$stat_vars
		matrix colnames pov_`typs'_vars_`p'= Pov_Mean_poor20 Pov_SE_poor20 Pov_Mean_nonpoor20  Pov_SE_nonpoor20
		matrix list pov_`typs'_vars_`p'
		matrix pov_`typs'_vars_combined_`p'=ttest_`typs'_vars_`p', J(rowsof(ttest_`typs'_vars_`p'),1,.), pov_`typs'_vars_`p'

		local m=`n'+35
		local q=`m'-2
		putexcel set "${output}/BHA_DRC_SDA Poverty 20 Percent Summary statistics_January_2023.xls", sheet("`typs'_vars - Poor20") modify
		qui putexcel A`q'="Province `p'" 
		if `p'==16 {
		    qui putexcel B`q'="South Kivu" 
		}
		if `p'==21 {
		    qui putexcel B`q'="Tanganyika" 
		}
		if `p'==23 {
		    qui putexcel B`q'="Kasai Oriental" 
		}
		if `p'==25 {
		    qui putexcel B`q'="Kasai Central" 
		}
		if `p'==26 {
		    qui putexcel B`q'="Kasai" 
		}
		
		qui putexcel A`m'=matrix(pov_`typs'_vars_combined_`p') , names 
		local n=`m'+10		
	}	
}	
	

	
*## Table A1 to A5 (A1-demog, A2-house, A3-washh, A4-ag, A5-oths)
*==================
* Table A6: Full regression coefficients and standard errors of the correlates of household poverty by provinces
* Figure 4-6


global house_vars house number_rooms floor_material_precarous /*floor_material_sand floor_material_cement floor_material_ceramic*/ /*
*/ /*floor_material_others*/ /*rool_material_metal rool_material_plalmleaf rool_material_weeds rool_material_others*/ rool_material_precarous /*
*/ /*wall_material_brick wall_material_mud  wall_material_wood wall_material_others*/ wall_material_precarous

global oths_vars /*table_chairs couch dresser*/ table_chairs_couch_dresser bedframe   bicycle motorvehicle /*boat watch*/ /*radio television*/ radio_tv_dvd /*dvd_player computer*/ phone 
 /*washer_machine iron fan AC */

global ag_vars agland farmsize /*lruminant_cattle*/ nb_cattle /*lruminant_other_cattle lruminant_others*/ /*
*/ /*sruminant_shoagts*/ nb_shoats /*sruminant_pigs*/ nb_pigs /*poultry*/ nb_poultry /*sruminant_rabits*/ /*plow*/    

global ag_vars agland farmsize lruminant_cattle  /*nb_cattle*/ /*lruminant_other_cattle lruminant_others*/ /*
*/ sruminant_shoagts  /*nb_shoats*/ sruminant_pigs /*nb_pigs*/ poultry /*nb_poultry*/ sruminant_rabits /*plow*/    

global washh_vars lamppetro /*stove refrigerator*/ /*
*/ /*cookplace_inhouse cookplace_sephouse cookplace_outdoor*/ cookplace_closedspace  /*cook_charcoal cook_woods cook_other*/ cook_woodsproduct /*drinkwater_safe*/  drinkwater_unsafe /*
*/ /*toilet_modern toilet_tradisafe*/ toilet_opendef water_to_washang bednet 

global demog_vars hh_rural hh_female hh_size hh_children_5 /*hh_children_5_17*/ hh_age /*
*/ /*hh_noschool*/ hh_primary hh_secondaryplus /*hh_tertiary*/ eletricity /*internet bank_account */  

**ALL HOUSEHOLDS 
*DRC- National
reg poor20 $demog_vars $house_vars $washh_vars $ag_vars $oths_vars   i.stratum [aw=hhweight] 
estimates store all_hh7

* By province
*-- all Households
reg poor20 $demog_vars $house_vars $washh_vars $ag_vars $oths_vars i.stratum [aw=hhweight] if  HH7==21 
estimates store all_hh7_21
reg poor20	$demog_vars $house_vars $washh_vars $ag_vars $oths_vars i.stratum [aw=hhweight] if  HH7==26 
estimates store all_hh7_26
reg poor20	$demog_vars $house_vars $washh_vars $ag_vars $oths_vars i.stratum [aw=hhweight]    if  HH7==25 
estimates store all_hh7_25

coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) || , ///
keep($demog_vars) xline(0)   legend(rows(1)) msymbol(s)  msize(medium) coeflabels(, notick labgap(5) labsize(huge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(huge)) subtitle(,size(huge))
graph export "${output}\Poor20_correlates_demog_Province_ALL.pdf", replace

coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($house_vars $washh_vars) xline(0)   legend(rows(1)) msymbol(D)  msize(medium) lcolor(red) coeflabels(, notick labgap(5) labsize(huge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(huge)) subtitle(,size(huge))
graph export "${output}\Poor20_correlates_house_wash_Province_ALL.pdf", replace

coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($ag_vars $oths_vars) xline(0)   legend(rows(1)) msymbol(s)  msize(medium) coeflabels(, notick labgap(5) labsize(huge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(huge)) subtitle(,size(huge))
graph export "${output}\Poor20_correlates_ag_nonag_assets_Province_ALL.pdf", replace

outreg2 [all_hh7_21 all_hh7_26 all_hh7_25 all_hh7] using  "${output}\Poor20_correlates_ALL.xls", addstat(Adjusted R-squared, e(r2_a))  dec(2) label  replace


 
 
 
*## ANALYSIS USING THE BOTTOM 20 PERCENT AS DEFINITION OF POVERTY
*=================================================================


*## Table A7 to A11 (A7-demog, A8-house, A9-washh, A10-ag, A11-oths)

**ALL HOUSEHOLDS
foreach typs in  demog house washh ag oths    {
*DRC National	
	*Distribution among all, poor and non-poor households
	matrix ttest_`typs'_vars=J(1,7,.)
	global stat_vars ""
	*di "$stat_`typs'_vars"	
	foreach x of global `typs'_vars {
		qui tabstat `x' [aw=hhweight], by(poor40)   statistics (mean semean) save // to get means that reflect the survey weights
		matrix meangroup=100*r(StatTotal)', 100*r(Stat2)',100*r(Stat1)'
		qui reg `x' poor40 [aw=hhweight] // to get pvalues that reflect the survey weights
		matrix b=e(b)
		matrix V=e(V)
		scalar pvalue=(2*ttail(e(df_r), abs(el(b,1,1)/sqrt(el(V,1,1)))))
		matrix ttest_`typs'_vars=ttest_`typs'_vars\(meangroup,pvalue)
		global stat_vars $stat_vars Mean_`x'  
	}
 

	matrix ttest_`typs'_vars=ttest_`typs'_vars[2..rowsof(ttest_`typs'_vars),.]
	matrix rownames ttest_`typs'_vars=$stat_vars
	matrix colnames ttest_`typs'_vars= Mean_all SE_all  Mean_poor40 SE_poor40 Mean_nonpoor40 SE_nonpoor40  Pvalue 

	*Poverty incidence among all, poor and non-poor households
	matrix pov_`typs'_vars=J(1,4,.)
	foreach x of global `typs'_vars {
		qui tabstat poor40 [aw=hhweight], by(`x')   statistics (mean semean) save // to get means that reflect the survey weights
		capture confirm matrix r(Stat2)
		if _rc==0 { 
			matrix meangroup=100*r(Stat2)',100*r(Stat1)'
		}
		if _rc!=0 { 
			matrix meangroup=J(1,4,.)
		}		
		matrix pov_`typs'_vars=pov_`typs'_vars\meangroup	
	}

	matrix pov_`typs'_vars=pov_`typs'_vars[2..rowsof(pov_`typs'_vars),.]
	matrix rownames pov_`typs'_vars=$stat_vars
	matrix colnames pov_`typs'_vars= Pov_Mean_poor40 Pov_SE_poor40 Pov_Mean_nonpoor40  Pov_SE_nonpoor40
	
	matrix pov_`typs'_vars_combined=ttest_`typs'_vars, J(rowsof(ttest_`typs'_vars),1,.), pov_`typs'_vars
	matrix list pov_`typs'_vars_combined
	
	putexcel set "${output}/BHA_DRC_SDA Poverty 40 Percent Summary statistics_January_2023.xls", sheet("`typs'_vars - Poor40", replace) modify
	qui putexcel A2="ALL HOUSEHOLDS" 
	qui putexcel A4="Poverty Summary Statistics - `typs'_vars" 
	qui putexcel A6="DRC National" 
	qui putexcel A8 =matrix(pov_`typs'_vars_combined) , names
 
*By province
	*Distribution among all, poor and non-poor households
	local n: word count $`typs'_vars 
	di "`n'"
	foreach p of global cfocus_provinces {	
		di "`p'"
		matrix ttest_`typs'_vars_`p'=J(1,7,.)
		foreach x of global `typs'_vars {
			qui tabstat `x' [aw=hhweight] if HH7==`p', by(poor40)   statistics (mean semean) save // to get means that reflect the survey weights
			matrix meangroup=100*r(StatTotal)', 100*r(Stat2)',100*r(Stat1)'
			qui reg `x' poor40 [aw=hhweight] if HH7==`p' // to get pvalues that reflect the survey weights
			matrix b=e(b)
			matrix V=e(V)
			scalar pvalue=(2*ttail(e(df_r), abs(el(b,1,1)/sqrt(el(V,1,1)))))
			matrix ttest_`typs'_vars_`p'=ttest_`typs'_vars_`p'\(meangroup,pvalue)		
		}

		matrix ttest_`typs'_vars_`p'=ttest_`typs'_vars_`p'[2..rowsof(ttest_`typs'_vars_`p'),.]
		matrix rownames ttest_`typs'_vars_`p'=$stat_vars
		matrix colnames ttest_`typs'_vars_`p'= Mean_all SE_all  Mean_poor40 SE_poor40 Mean_nonpoor40 SE_nonpoor40  Pvalue

	*Poverty incidence among all, poor and non-poor households
		matrix pov_`typs'_vars_`p'=J(1,4,.)
		foreach x of global `typs'_vars {
			qui tabstat poor40 [aw=hhweight] if HH7==`p', by(`x')   statistics (mean semean) save // to get means that reflect the survey weights
			capture confirm matrix r(Stat2)
			if _rc==0 { 
				matrix meangroup=100*r(Stat2)',100*r(Stat1)'
			}
			if _rc!=0 { 
				matrix meangroup=J(1,4,.)
			}	
			matrix pov_`typs'_vars_`p'=pov_`typs'_vars_`p'\meangroup				
		}

		matrix pov_`typs'_vars_`p'=pov_`typs'_vars_`p'[2..rowsof(pov_`typs'_vars_`p'),.]
		matrix rownames pov_`typs'_vars_`p'=$stat_vars
		matrix colnames pov_`typs'_vars_`p'= Pov_Mean_poor40 Pov_SE_poor40 Pov_Mean_nonpoor40  Pov_SE_nonpoor40
		matrix list pov_`typs'_vars_`p'
		matrix pov_`typs'_vars_combined_`p'=ttest_`typs'_vars_`p', J(rowsof(ttest_`typs'_vars_`p'),1,.), pov_`typs'_vars_`p'

		local m=`n'+35
		local q=`m'-2
		putexcel set "${output}/BHA_DRC_SDA Poverty 40 Percent Summary statistics_January_2023.xls", sheet("`typs'_vars - Poor40") modify
		qui putexcel A`q'="Province `p'" 
		if `p'==16 {
		    qui putexcel B`q'="South Kivu" 
		}
		if `p'==21 {
		    qui putexcel B`q'="Tanganyika" 
		}
		if `p'==23 {
		    qui putexcel B`q'="Kasai Oriental" 
		}
		if `p'==25 {
		    qui putexcel B`q'="Kasai Central" 
		}
		if `p'==26 {
		    qui putexcel B`q'="Kasai" 
		}
		
		qui putexcel A`m'=matrix(pov_`typs'_vars_combined_`p') , names 
		local n=`m'+10		
	}	
}	
	

	
*## 
*==================
* Table A12: Full regression coefficients and standard errors of the correlates of household poverty by provinces
* Figure xx


global house_vars house number_rooms floor_material_precarous /*floor_material_sand floor_material_cement floor_material_ceramic*/ /*
*/ /*floor_material_others*/ /*rool_material_metal rool_material_plalmleaf rool_material_weeds rool_material_others*/ rool_material_precarous /*
*/ /*wall_material_brick wall_material_mud  wall_material_wood wall_material_others*/ wall_material_precarous

global oths_vars /*table_chairs couch dresser*/ table_chairs_couch_dresser bedframe   bicycle motorvehicle /*boat watch*/ /*radio television*/ radio_tv_dvd /*dvd_player computer*/ phone 
 /*washer_machine iron fan AC */

global ag_vars agland farmsize /*lruminant_cattle*/ nb_cattle /*lruminant_other_cattle lruminant_others*/ /*
*/ /*sruminant_shoagts*/ nb_shoats /*sruminant_pigs*/ nb_pigs /*poultry*/ nb_poultry /*sruminant_rabits*/ /*plow*/    

global ag_vars agland farmsize lruminant_cattle  /*nb_cattle*/ /*lruminant_other_cattle lruminant_others*/ /*
*/ sruminant_shoagts  /*nb_shoats*/ sruminant_pigs /*nb_pigs*/ poultry /*nb_poultry*/ sruminant_rabits /*plow*/    

global washh_vars lamppetro /*stove refrigerator*/ /*
*/ /*cookplace_inhouse cookplace_sephouse cookplace_outdoor*/ cookplace_closedspace  /*cook_charcoal cook_woods cook_other*/ cook_woodsproduct /*drinkwater_safe*/  drinkwater_unsafe /*
*/ /*toilet_modern toilet_tradisafe*/ toilet_opendef water_to_washang bednet 

global demog_vars hh_rural hh_female hh_size hh_children_5 /*hh_children_5_17*/ hh_age /*
*/ /*hh_noschool*/ hh_primary hh_secondaryplus /*hh_tertiary*/ eletricity /*internet bank_account */  

**ALL HOUSEHOLDS 
*DRC- National
reg poor40 $demog_vars $house_vars $washh_vars $ag_vars $oths_vars   i.stratum [aw=hhweight] 
estimates store all_hh7

* By province
*-- all Households
reg poor40 $demog_vars $house_vars $washh_vars $ag_vars $oths_vars i.stratum [aw=hhweight] if  HH7==21 
estimates store all_hh7_21
reg poor40	$demog_vars $house_vars $washh_vars $ag_vars $oths_vars i.stratum [aw=hhweight] if  HH7==26 
estimates store all_hh7_26
reg poor40	$demog_vars $house_vars $washh_vars $ag_vars $oths_vars i.stratum [aw=hhweight]    if  HH7==25 
estimates store all_hh7_25

coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) || , ///
keep($demog_vars) xline(0)   legend(rows(1)) msymbol(s)  msize(medium) coeflabels(, notick labgap(5) labsize(huge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(huge)) subtitle(,size(huge))
graph export "${output}\Poor40_correlates_demog_Province_ALL.pdf", replace

coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($house_vars $washh_vars) xline(0)   legend(rows(1)) msymbol(D)  msize(medium) lcolor(red) coeflabels(, notick labgap(5) labsize(huge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(huge)) subtitle(,size(huge))
graph export "${output}\Poor40_correlates_house_wash_Province_ALL.pdf", replace

coefplot all_hh7_21, bylabel(Tanganyika)  || all_hh7_26, bylabel(Kasai) || all_hh7_25, bylabel(Kasai Central) ||, ///
keep($ag_vars $oths_vars) xline(0)   legend(rows(1)) msymbol(s)  msize(medium) coeflabels(, notick labgap(5) labsize(huge)) byopts(row(1)) levels(90)  graphregion(margin(zero)) plotregion(margin(zero)) xsize(15) ysize(5) xlab(,labsize(huge)) subtitle(,size(huge))
graph export "${output}\Poor40_correlates_ag_nonag_assets_Province_ALL.pdf", replace

outreg2 [all_hh7_21 all_hh7_26 all_hh7_25 all_hh7] using  "${output}\Poor40_correlates_ALL.xls", addstat(Adjusted R-squared, e(r2_a))  dec(2) label  replace


 
